@@ -49,7 +49,7 @@ class CfnDataCatalog(
         type: builtins.str,
         description: typing.Optional[builtins.str] = None,
         parameters: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Mapping[builtins.str, builtins.str]]] = None,
-        tags: typing.Optional["CfnDataCatalog.TagsProperty"] = None,
+        tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]] = None,
     ) -> None:
         """Create a new ``AWS::Athena::DataCatalog``.
 
@@ -168,46 +168,6 @@ class CfnDataCatalog(
     ) -> None:
         jsii.set(self, "parameters", value)
 
-    @jsii.data_type(
-        jsii_type="@aws-cdk/aws-athena.CfnDataCatalog.TagsProperty",
-        jsii_struct_bases=[],
-        name_mapping={"tags": "tags"},
-    )
-    class TagsProperty:
-        def __init__(
-            self,
-            *,
-            tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]] = None,
-        ) -> None:
-            """
-            :param tags: ``CfnDataCatalog.TagsProperty.Tags``.
-
-            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-datacatalog-tags.html
-            """
-            self._values: typing.Dict[str, typing.Any] = {}
-            if tags is not None:
-                self._values["tags"] = tags
-
-        @builtins.property
-        def tags(self) -> typing.Optional[typing.List[aws_cdk.core.CfnTag]]:
-            """``CfnDataCatalog.TagsProperty.Tags``.
-
-            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-datacatalog-tags.html#cfn-athena-datacatalog-tags-tags
-            """
-            result = self._values.get("tags")
-            return result
-
-        def __eq__(self, rhs: typing.Any) -> builtins.bool:
-            return isinstance(rhs, self.__class__) and rhs._values == self._values
-
-        def __ne__(self, rhs: typing.Any) -> builtins.bool:
-            return not (rhs == self)
-
-        def __repr__(self) -> str:
-            return "TagsProperty(%s)" % ", ".join(
-                k + "=" + repr(v) for k, v in self._values.items()
-            )
-
 
 @jsii.data_type(
     jsii_type="@aws-cdk/aws-athena.CfnDataCatalogProps",
@@ -228,7 +188,7 @@ class CfnDataCatalogProps:
         type: builtins.str,
         description: typing.Optional[builtins.str] = None,
         parameters: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Mapping[builtins.str, builtins.str]]] = None,
-        tags: typing.Optional[CfnDataCatalog.TagsProperty] = None,
+        tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]] = None,
     ) -> None:
         """Properties for defining a ``AWS::Athena::DataCatalog``.
 
@@ -240,8 +200,6 @@ class CfnDataCatalogProps:
 
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html
         """
-        if isinstance(tags, dict):
-            tags = CfnDataCatalog.TagsProperty(**tags)
         self._values: typing.Dict[str, typing.Any] = {
             "name": name,
             "type": type,
@@ -294,7 +252,7 @@ class CfnDataCatalogProps:
         return result
 
     @builtins.property
-    def tags(self) -> typing.Optional[CfnDataCatalog.TagsProperty]:
+    def tags(self) -> typing.Optional[typing.List[aws_cdk.core.CfnTag]]:
         """``AWS::Athena::DataCatalog.Tags``.
 
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-tags
@@ -584,7 +542,7 @@ class CfnWorkGroup(
         description: typing.Optional[builtins.str] = None,
         recursive_delete_option: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
         state: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, aws_cdk.core.CfnTag]]]] = None,
+        tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]] = None,
         work_group_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.WorkGroupConfigurationProperty"]] = None,
         work_group_configuration_updates: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.WorkGroupConfigurationUpdatesProperty"]] = None,
     ) -> None:
@@ -1205,7 +1163,7 @@ class CfnWorkGroupProps:
         description: typing.Optional[builtins.str] = None,
         recursive_delete_option: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
         state: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, aws_cdk.core.CfnTag]]]] = None,
+        tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]] = None,
         work_group_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, CfnWorkGroup.WorkGroupConfigurationProperty]] = None,
         work_group_configuration_updates: typing.Optional[typing.Union[aws_cdk.core.IResolvable, CfnWorkGroup.WorkGroupConfigurationUpdatesProperty]] = None,
     ) -> None:
@@ -1277,9 +1235,7 @@ class CfnWorkGroupProps:
         return result
 
     @builtins.property
-    def tags(
-        self,
-    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, aws_cdk.core.CfnTag]]]]:
+    def tags(self) -> typing.Optional[typing.List[aws_cdk.core.CfnTag]]:
         """``AWS::Athena::WorkGroup.Tags``.
 
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-tags
